# SPDX-FileCopyrightText: skforecast team
# SPDX-FileCopyrightText: 2026 bartzbeielstein
# SPDX-License-Identifier: AGPL-3.0-or-later AND BSD-3-Clause

"""
Time series differentiator transformer.

All classes are imported from spotforecast2_safe.preprocessing._differentiator.
"""

from spotforecast2_safe.preprocessing._differentiator import TimeSeriesDifferentiator

__all__ = ["TimeSeriesDifferentiator"]
